package sun.nio.fs;

import java.util.HashMap;
import java.util.Map;
import java.io.IOException;
import java.nio.file.attribute.UserPrincipal;
import java.nio.file.attribute.AclFileAttributeView;
import java.nio.file.attribute.PosixFileAttributeView;
import java.nio.file.attribute.FileAttributeView;
import java.nio.file.attribute.FileOwnerAttributeView;

final class FileOwnerAttributeViewImpl implements FileOwnerAttributeView, DynamicFileAttributeView
{
    private static final String OWNER_NAME = "owner";
    private final FileAttributeView view;
    private final boolean isPosixView;
    
    FileOwnerAttributeViewImpl(PosixFileAttributeView view) {
        this.view = view;
        this.isPosixView = true;
    }
    
    FileOwnerAttributeViewImpl(AclFileAttributeView view) {
        this.view = view;
        this.isPosixView = false;
    }
    
    @Override
    public String name() {
        return "owner";
    }
    
    @Override
    public void setAttribute(String str, Object o) throws IOException {
        if (str.equals("owner")) {
            this.setOwner((UserPrincipal)o);
            return;
        }
        throw new IllegalArgumentException("'" + this.name() + ":" + str + "' not recognized");
    }
    
    @Override
    public Map<String, Object> readAttributes(String[] array) throws IOException {
        HashMap<String, UserPrincipal> hashMap = new HashMap();
        int length = array.length;
        int i = 0;
        while (i < length) {
            String str = array[i];
            if (str.equals("*") || str.equals("owner")) {
                hashMap.put("owner", this.getOwner());
                ++i;
            }
            else {
                throw new IllegalArgumentException("'" + this.name() + ":" + str + "' not recognized");
            }
        }
        return hashMap;
    }
    
    @Override
    public UserPrincipal getOwner() throws IOException {
        if (this.isPosixView) {
            return ((PosixFileAttributeView)this.view).readAttributes().owner();
        }
        return ((AclFileAttributeView)this.view).getOwner();
    }
    
    @Override
    public void setOwner(UserPrincipal userPrincipal) throws IOException {
        if (this.isPosixView) {
            ((PosixFileAttributeView)this.view).setOwner(userPrincipal);
        }
        else {
            ((AclFileAttributeView)this.view).setOwner(userPrincipal);
        }
    }
}
